@@ -12,12 +12,12 @@
  ***************************************************************************/
 
 #include "kgpgimport.h"
-#include "kgpg_debug.h"
+#include "kgpg_general_debug.h"
 
 #include "model/kgpgitemmodel.h"
 #include "core/KGpgKeyNode.h"
 
-#include <QDebug>
+
 
 #include <KLocalizedString>
 
@@ -75,9 +75,9 @@ KGpgImport::getImportedIds(const QStringList &log, const int reason)
 		}
 
 		bool ok;
-		unsigned char code = tmpstr.left(space).toUInt(&ok);
+		unsigned char code = tmpstr.leftRef(space).toUInt(&ok);
 		if (!ok) {
-			qCDebug(KGPG_LOG_GENERAL) << __LINE__ << "invalid format:" << str << space << tmpstr.left(space - 1);
+			qCDebug(KGPG_LOG_GENERAL) << __LINE__ << "invalid format:" << str << space << tmpstr.leftRef(space - 1);
 			continue;
 		}
 
